DialogueKit |release| documentation
=====================================

DialogueKit is a framework for building and evaluating conversational information access systems.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   usage
   concepts
   components
   nlu
   nlg
   external_agents
   dialogue_export
   :ref:`modindex`

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

